# aeneas Main Library 

This Python module (directory) contains the main ``aeneas`` library.

Unit tests are contained in the ``aeneas.tests`` submodule.

The ``aeneas.tools`` submodule define several command line tools
which use the main ``aeneas`` library.



